@@ -137,6 +137,7 @@ module Diagrams.Core
        , AName
        , Name, IsName(..)
        , Qualifiable(..), (.>)
+       , eachName
 
          -- ** Subdiagram maps
 
@@ -194,8 +195,7 @@ module Diagrams.Core
          -- * Diagrams
 
        , QDiagram, Diagram, mkQD, pointDiagram
-       , envelope, trace, subMap, names, query, sample
-       , value, resetValue, clearValue
+       , envelope, trace, subMap, names, query
 
        , nameSub
        , withName
